"use client"
import { useSession } from 'next-auth/react'
import Image from 'next/image';
import { redirect } from 'next/navigation';
import React, { useEffect, useState } from 'react'
import toast from 'react-hot-toast';


const ProfilePage = () => {
  //use session
  const session = useSession();
  const {status} = session;
  //profile update
  const [userName, setUserName] = useState('');
  const [image, setImage] = useState('');


  useEffect(() => {
    if(status === 'authenticated'){
      setUserName(session.data.user.name)
      setImage(session.data.user.image)
    }
  },[session, status])


  async function handleInfoUpdate(ev){
    ev.preventDefault()

    const savingPromise = new Promise(async (resolve, reject) => {
      const response = await fetch('/api/profile', {
        method: 'PUT',
        headers: {'Content-Type': 'application/json'},
        body: JSON.stringify({name:userName, image}),
      });
      if(response.ok) 
        resolve()
      else
        reject()
    });
    await toast.promise(savingPromise, {
      loading: 'Saving',
      success: 'Profile is saved!',
      error: 'Fail to update profile',
    })
  }

  async function handleImgchange(ev){
    const files = ev.target.files;
    if(files?.length === 1){
      const data = new FormData;
      data.set('file', files[0]);
      
      
      const uploadPromise =  fetch('/api/upload', {
          method: 'POST',
          body: data,
        }).then(response => {
          if(response.ok){
            return response.json().then(link => {
              setImage(link)
            });
          }
          throw new Error('Something went wrong!')
        });
      
      
      await toast.promise(uploadPromise, {
        loading: 'Uploading',
        success: 'An image is uploaded',
        error: 'Fail to upload image!',
      })
      
    }
  }


  if(status === 'loading'){
    return 'Loading...'
  }
  if(status === 'unauthenticated'){
    return redirect('/login');
  }



  return (
    <div className='px-5'>
      <p className='text-center text-2xl font-semibold uppercase mb-5 text-[#FF5580]'>Profile</p>
      <div className='max-w-md mx-auto'>
        <div className='flex flex-col gap-2 justify-center items-center max-w-[100px] mx-auto'>
          {image && (
            <Image src={image} width={100} height={100} alt={'user-image'} className='rounded-full'/>
          )}
          <label>
            <input type='file' onChange={handleImgchange} className='hidden'/>
            <span className='px-2 py-1 border border-[#DCA0AE] rounded-md text-sm cursor-pointer'>Edit</span>
          </label>
        </div>
        <form className='mt-5' onSubmit={handleInfoUpdate}>
          <input type='text' placeholder='Name' value={userName} onChange={ev => setUserName(ev.target.value)}/>
          <input type='text' value={session.data.user.email} disabled={true} className='disabled:bg-gray-200 disabled:text-gray-400'/>
          <button className='rounded-md bg-[#DCA0AE] text-white hover:opacity-80 duration-300 p-2 font-semibold block w-full disabled:cursor-not-allowed'>Save</button>
        </form>
      </div>
    </div>
  )
}

export default ProfilePage